abacusai.problem_type — AbacusAI documentation

# abacusai.problem_type

## Classes

`ProblemType` | Description of a problem type which is the common underlying problem for different use cases.

## Module Contents

class abacusai.problem_type.ProblemType(client, problemType=None, requiredFeatureGroupType=None, optionalFeatureGroupTypes=None, useCasesSupportCustomAlgorithm=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  Description of a problem type which is the common underlying problem for different use cases.

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - problemType (str) – Name of the problem type

    - requiredFeatureGroupType (str) – The required feature group types to train for this problem type

    - optionalFeatureGroupTypes (list[str]) – The optional feature group types can be used to train for this problem type

    - useCasesSupportCustomAlgorithm (list) – A list of use cases that support custom algorithms

  problem_type
  required_feature_group_type
  optional_feature_group_types
  use_cases_support_custom_algorithm
  deprecated_keys
  __repr__()
  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict